@@ -3,7 +3,7 @@ use strict;
 
 package Net::OAuth2::Scheme;
 BEGIN {
-  $Net::OAuth2::Scheme::VERSION = '0.010001_001';
+  $Net::OAuth2::Scheme::VERSION = '0.010002_002';
 }
 # ABSTRACT: Token scheme definition framework for OAuth 2.0
 
@@ -88,14 +88,20 @@ Net::OAuth2::Scheme - Token scheme definition framework for OAuth 2.0
 
 =head1 VERSION
 
-version 0.010001_001
+version 0.010002_002
 
 =head1 SYNOPSIS
 
 Exactly how the code would look depends on the respective server
 frameworks in use and we're trying to be agnostic about that, but...
 
-  our %access_options = (... options describing token scheme ...);
+  our %access_options = (
+    transport => 'bearer',
+    format => 'bearer_handle',
+    vtable => 'shared_cache',
+    cache => ...
+    # see L<Net::OAuth2::Scheme::Factory> for other possibilities
+  );
 
   ##
   ## Within the Client Implementation
@@ -350,7 +356,7 @@ B<vtable_pull> below).
  $scheme = new(%scheme_options);
  $scheme = new(factory => $factory_class, %scheme_options);
 
-See L<Net::OAuth::Scheme::Factory>, the default factory class,
+See L<Net::OAuth2::Scheme::Factory>, the default factory class,
 for what can be in I<%scheme_options>.
 
 Use the second form if you want to substitute your own $factory_class;
